#
# spec file for package colorhug-client
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           colorhug-client
Version:        0.2.8
Release:        1.28
Summary:        Tools for the Hughski Colorimeter
License:        GPL-2.0+
Group:          Productivity/Graphics/Other
Url:            http://www.hughski.com/
Source0:        http://people.freedesktop.org/~hughsient/releases/%{name}-%{version}.tar.xz
BuildRequires:  docbook-utils
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  pkgconfig(bash-completion) >= 2.0
BuildRequires:  pkgconfig(colord) >= 1.2.3
BuildRequires:  pkgconfig(colord-gtk) >= 0.1.24
BuildRequires:  pkgconfig(gio-2.0) >= 2.25.9
BuildRequires:  pkgconfig(glib-2.0) >= 2.31.10
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 2.91.0
BuildRequires:  pkgconfig(gusb) >= 0.2.2
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.10
BuildRequires:  pkgconfig(libsoup-2.4)
Recommends:     %{name}-lang

%description
The Hughski ColorHug colorimeter is a low cost open-source hardware
sensor used to calibrate screens.

This package includes the client tools which allows the user to upgrade
the firmware on the sensor or to access the sensor from command line
scripts.

%lang_package

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file -u -r -G 'CCMX Loader' com.hughski.ColorHug.CcmxLoader Graphics Color
%suse_update_desktop_file -u -r -G 'Display Analysis' com.hughski.ColorHug.DisplayAnalysis Graphics Color
%suse_update_desktop_file -u -r -G 'Firmware Updater' com.hughski.ColorHug.FlashLoader Graphics Color
%suse_update_desktop_file -u -r -G 'Documentation' colorhug-docs Graphics Color
%suse_update_desktop_file -u -r -G 'Backlight' com.hughski.ColorHug.Backlight Graphics Color

%find_lang %{name}

%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%doc README AUTHORS NEWS COPYING
%dir %{_datadir}/appdata
%{_datadir}/appdata/*
%dir %{_datadir}/colorhug-client
%{_datadir}/colorhug-client
%{_libexecdir}/colorhug*
%{_bindir}/colorhug*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/colorhug.png
%{_datadir}/icons/hicolor/*/apps/colorhug-backlight.png
%{_datadir}/icons/hicolor/*/apps/colorhug-flash.png
%{_datadir}/icons/hicolor/*/apps/colorhug-ccmx.png
%{_datadir}/icons/hicolor/*/apps/colorhug-refresh.png
%{_datadir}/icons/hicolor/*/apps/colorimeter-colorhug-inactive.png
%{_datadir}/icons/hicolor/scalable/apps/colorhug.svg
%{_datadir}/icons/hicolor/*/mimetypes/application-x-ccmx.png
%{_datadir}/icons/hicolor/scalable/mimetypes/application-x-ccmx.svg
%{_datadir}/glib-2.0/schemas/com.hughski.colorhug-client.gschema.xml
%{_mandir}/man1/*.1%{?ext_man}
%{_datadir}/bash-completion/completions/colorhug-cmd

%files lang -f %{name}.lang

%changelog
* Sat Nov  4 2017 aavindraa@gmail.com
- Update to version 0.2.8
  * Add a --device argument to colorhug-cmd
  * Support the ColorHugALS in SensorHID mode for backlight changes
  * Fix a potential crash when doing set-calibration-ccmx
- Lint spec file
* Mon Apr 20 2015 kkaempf@suse.com
- Update to version 0.2.7
  * Fix a typo to allow exporting results again
  * Never auto-dim less than 5%%
- Update to version 0.2.6
  * This release make the CCMX loader adhere to the GNOME 3
    guidelines.
* Fri Dec 19 2014 kkaempf@suse.com
- Update to version 0.2.5
  New Features:
  - Add a simple man page and AppData file for colorhug-refresh
    (Richard Hughes)
  Bugfixes:
  - Add keywords to the various desktop files (Richard Hughes)
  - Do not install the bash-completion files in /etc (Richard Hughes)
- Update to version 0.2.4
  New Features:
  - Add a NSI script to build the Windows installer (Richard Hughes)
  - Add colorhug-refresh for measuring display latency and refresh
    rates (Richard Hughes)
  - Add windows resource files for all executables (Richard Hughes)
  Bugfixes:
  - Do not use deprecated libgusb API (Richard Hughes)
  - Don't install Linux-only content when compiling with MinGW
    (Richard Hughes)
  - Make libcanberra-gtk3 optional (Richard Hughes)
  - Remove colorhug-inhx32-to-bin and move functionality into
    colorhug-cmd (Richard Hughes)
  - Support the ColorHug2 in the example code (Richard Hughes)
* Mon Nov 10 2014 kkaempf@suse.com
- Update to version 0.2.3
  New Features:
  - Show the Yxy and sRGB values when using take-readings-xyz
    (Richard Hughes)
  Bugfixes:
  - Do not fail TakeReadingRaw when using CH2 (Richard Hughes)
  - Do not show CCMX matrices for different device types
    (Richard Hughes)
* Mon Sep 15 2014 kkaempf@suse.com
- Update to version 0.2.2
  - This release requires colord >= 1.2.3
  New Features:
  - Load the colorhug-spectro-utils data file from a GResource
  - Support ColorHug2 in colorhug-ccmx and colorhug-flash
  - Support getting and setting the DAC value on ColorHug+
  Bugfixes:
  - Do not use deprecated widgets in the spectro tool
  - Don't set the multiplier or integral on v2 hardware
  - Fix autogen failure with new gettexts
  - Remove suspicious usage of sizeof with a numeric constant
  - Use ch_device_check_firmware() to verify the firmware
- drop colorhug-client-colorhug_plus.patch, upstream
* Fri Feb  7 2014 dimstar@opensuse.org
- Update to version 0.2.1:
  + New Features: Add an AppData file for colorhug-flash and
    colorhug-ccmx.
  + Bugfixes:
  - Find the new ColorHug VID:PID in the USB example.
  - Do not use g_type_init() for new versions of GLib.
  - Rely on intltool >= 0.50 for GSettings translation.
- Add colorhug-client-colorhug_plus.patch: Rename 'ColorHug
  Spectro' to 'ColorHug+' for trademark reasons.
* Wed Sep  4 2013 coolo@suse.com
- Update to version 0.2.0:
  + New Features:
  - Add a command to get the spectral data from the CCD.
  - Add a 'get-adc-vrefs' command to show the ADC Vref+ and
    Vref-.
  - Add help buttons to colorhug-flash and colorhug-ccmx.
  - Add some yelp documentation for the ColorHug device.
  - Add the ability to get and set CCD calibration values.
  - Support setting the blue LED in the ColorHug Spectro.
  + Bugfixes:
  - Do not refresh the calibration data twice when setting a
    custom CCMX.
  - Do not use deprecated colord functionality.
  - Remove the internal libcolorhug and depend on the system
    copy.
  - Set a title when generating a CCMX file.
  - Use gnome-autogen.sh to setup yelp rather than rolling our
    own thing.
- Add itstool BuildRequires, new dependency.
* Tue Apr 23 2013 dimstar@opensuse.org
- Update to version 0.1.14:
  + New Features:
  - Compile the GtkBuilder files as a GResources to speed up
    startup.
  - Add a 'ccmx-upload' command to colorhug-cmd.
  - Allow the user to easily generate a CCMX correction matrix.
  + Bugfixes:
  - Use the UTF-8 'â rather than '...' in UI code.
  - Sort the profiles by name in colorhug-ccmx.
  - Don't use the deprecated INCLUDES in Makefile.am.
  - Never use -Werror when building.
  - Fix two difficult to translate strings.
  - Use an external libcolorhug if it exists rather than the
    internal copy.
- Changes from version 0.1.13:
  + New Features:
  - Add various demo programs for resetting the ColorHug.
  - Add a utility program to interface with the ColorHug Spectro.
  - Add client support for getting the device ambient
    temperature.
  - Add commands to read and write from the SRAM.
  - Add defines for the ColorHug Spectro.
  - Allow the user to flash an Intel HEX file from the command
    line.
  - Show the spectro temperature in the power utility.
  + Bugfixes:
  - Add self-test to the list of completion commands.
  - Add the ChSha1 symbol to the introspection data.
  - Add the missing GObjectIntrospection markup to ChDeviceQueue.
  - Cope with device errors without aborting when taking a raw
    measurement.
  - Don't return flashing success when the device failed to
    re-appear.
  - Fix flashing firmware with libusbx 1.0.13.
  - Fix make check when a ColorHug Spectro is inserted.
  - Fix the example to work when firmware > 1.2.0 is used.
  - Fix up the remaining introspection warnings.
  - Increase the device reset timeout for slow USB hubs.
  - Only require colord-gtk when building the debugging tools.
  - Remove some dead code spotted by coverity.
- Drop libcolorhug1 and libcolorhug-devel sub-packages: the library
  was moved to colord.
* Fri Nov  2 2012 p.drouand@gmail.com
- Update to 0.1.12 version :
  New Features:
  - Add colorhug-profile to compare the measurement modes (Richard Hughes)
  - Add subcommands to get and set the measurement mode (Richard Hughes)
  Bugfixes:
  - Accept full HID packets from devices with firmware >= 1.2.0 (Richard Hughes)
  - Fix a small memory leak when commands with helpers and callbacks fail (Richard Hughes)
  - Return a uint32 type for TAKE_READING_RAW (Richard Hughes)
- Remove unused conditional macros
* Sun Apr 22 2012 mrdocs@opensuse.org
-add proper copyright to the spec file
* Fri Apr 20 2012 vuntz@opensuse.org
- Change BuildRequires to pkgconfig() style:
  + Old ones: glib2-devel, gtk3-devel, libcanberra-devel,
    libcolord-devel, libgusb2-devel, liblcms2-devel, libsoup-devel.
  + New ones: colord, gio-2.0, glib-2.0, gmodule-2.0, gobject-2.0,
    gtk+-3.0, gusb, lcms2, libcanberra-gtk3, libsoup-2.4.
- Remove unneeded BuildRequires: gettext, libcanberra-gtk3-0,
  sqlite-devel.
- Change license tag from GPL-2.0 to GPL-2.0+.
- Split translations in a lang subpackage.
- General cleanup of spec file for inclusion in Factory.
* Wed Apr 18 2012 kkaempf@suse.com
- Version 0.1.8
  Released: 2012-04-17
  New Features:
  - Add a libusb0.1 example program that can run on RHEL5
  - Add a simple colorhug-ccmx icon
  - Make a sound when colorhug-flash fails or completes the update
  Bugfixes:
  - Add gmodule-2.0 to the GLib configure check
  - Automatically use the correct proxy server using glib-networking
  - Check the buffer size before attempting to parse
  - Don't assume const data is available when verifying firmware
  - Keep track of the device state in ChDeviceQueue
  - Prevent critical warnings when doing 'colorhug list-calibration'
  - Use the device state to work out if there are pending commands
* Fri Mar 16 2012 kkaempf@suse.com
- Version 0.1.7
  Released: 2012-03-15
  New Features:
  - Add a class responsible for async-queued-operations to multiple
    devices
  - Allow the user to update to test firmware if enabled in GSettings
  - Create a libcolorhug library that is designed for low level
    access to the device
  Bugfixes:
  - Add self test code to test the new incomplete-request functionality
  - Convert colorhug-ccmx to using ChDeviceQueue to decrease the
    startup delay
  - Convert colorhug-flash to using ChDeviceQueue to increase the
    flash speed
  - Convert the colormgr tool to using ChDeviceQueue
  - Correctly detect the failure to re-enumerate
  - Do not hardcode the server path, instead set it in the GSettings
    schema
  - Do not show an empty warning box if there is no firmware flash
    warning
  - Do not use g_usleep() when waiting for a device reconnect
* Mon Mar  5 2012 kkaempf@suse.com
- Update to version 0.1.6
  Released: 2012-03-04
  New Features:
  - Add a flash-firmware-force command (Richard Hughes)
  - Add a new icon for colorhug-flash (Lapo Calamandrei)
  - Add a new inactive colorimeter-colorhug icon for future use (Lapo
    Calamandrei)
  - Add support for getting and setting the PCB errata value
    (Richard Hughes)
  - Add support for TakeReadingArray and plot a simple graph with the
    results (Richard Hughes)
  - Allow the user to set the default LED correction matrix (Richard
    Hughes)
  Bugfixes:
  - Check the calibration determinant before writing to the device
    (Richard Hughes)
  - Do not write temp files with predictable names to /tmp (Richard
    Hughes)
  - Implement loading CCMX from file (Michal Čihař)
  - Increase the device reconnect timeout after flashing (Richard
    Hughes)
  - Intialize leds to 0 in ch_device_cmd_get_leds() (Jussi Kukkonen)
  - Recognise TYPE_FACTORY in the ccmx loader (Richard Hughes)
  - Remove all locale dependent string parsing functions (Richard
    Hughes)
  - Repair device only once while forced (Michal Čihař)
  - Set correct return value (Michal Čihař)
  - set_leds/get_leds() argument is not ChStatusLed, but guint8
    (Jussi Kukkonen)
  - Use G_GSIZE_FORMAT when printing gsize values (Jussi Kukkonen)
* Fri Jan 27 2012 kkaempf@suse.com
- Update to 0.1.5
  Released: 2012-01-26
  Notes:
  - We've now switched to a XML manifest format which allows us to check
    the size and sha1sum of the firmware file, and also to show the user
    any warnings about the new firmware.
  New Features:
  - Add an interactive version of 'colorhug set-dark-offsets'
    (Richard Hughes)
  - Add a --repair command line argument to colorhug-ccmx (Richard
    Hughes)
  - Add a simple HID client example (Richard Hughes)
  - Added name and email fields in client (Matthew Hirsch)
  - Add icons for the application/x-ccmx mime type (Richard Hughes)
  - Add some raw EEPROM commands to the command line tool (Richard
    Hughes)
  - Allow the user to flash stand alone files with colorhug-flash
    (Richard Hughes)
  - Check the SHA1 of the firmware before using it (Richard Hughes)
  - Show warning messages about firmware in a modal dialog box
    (Richard Hughes)
  Bugfixes:
  - Always pad the flash .bin file to a 64 byte chunk (Richard Hughes)
  - Fix handing device endianess (Michal Čihař)
  - Increase the USB timeout for dark reads (Richard Hughes)
  - Show the user the sensor conditions before showing CLI results
    (Richard Hughes)
* Wed Jan 11 2012 kkaempf@suse.com
- Version 0.1.4
  New Features:
  - A massive number of new translations from Transifex, thanks!
  - Add a missing manpage for colorhug-ccmx (Michal Čihař)
  Bugfixes:
  - Add transifex integration (Richard Hughes)
  - Add some button tooltips (Richard Hughes)
  - Move the command helpers out of ChClient (Richard Hughes)
  - Ensure we never delete the factory calibration matrix in
    colorhug-ccmx (Richard Hughes)
  - Allow the user to repair a device without a factory calibration
    matrix (Richard Hughes)
* Mon Jan  2 2012 kkaempf@suse.com
- Initial package release, version 0.1.3
